@@ -1,7 +1,7 @@
 module OrdinaryDiffEqFunctionMap
 
 import OrdinaryDiffEqCore: isfsal, beta2_default, beta1_default, OrdinaryDiffEqAlgorithm,
-                           initialize!, perform_step!, @unpack, unwrap_alg,
+                           initialize!, perform_step!, unwrap_alg,
                            OrdinaryDiffEqMutableCache,
                            alg_cache, @cache, _ode_addsteps!, _ode_interpolant!,
                            _ode_interpolant, get_fsalfirstlast,
